@@ -54,8 +54,6 @@ def process_caris_json(infile: str, outpath: str, file_name: str, ingest_status:
         data = all_data["root"]
     f.close()
 
-    manifest = {}
-
     somatic_filename = None
     germline_filename = None
 
@@ -104,9 +102,7 @@ def process_caris_json(infile: str, outpath: str, file_name: str, ingest_status:
         for filename in files["bam"]:
             pysam.index(filename)
 
-    manifest["tests"] = [metadata]
-
-    create_yaml(manifest, file_name, ingest_status)
+    create_yaml(metadata, file_name, ingest_status)
 
     # Return VCF files for immediate processing
     result = {}
