@@ -58,7 +58,6 @@ def extract_start_and_end_positions(fusion_variant: dict, position1: str, positi
 
 def extract_fusion_variant(
     results_payload_dict: dict,
-    sample_id: str,
     base_xml_name: str,
     output_dir: str,
     log: Logger,
@@ -81,7 +80,7 @@ def extract_fusion_variant(
                     fusion_variant, "@pos1", "@pos2"
                 )
                 fusion_variant_value = {
-                    "sample_id": fusion_variant.get("dna-evidence", {}).get("@sample", sample_id),
+                    "sample_id": base_xml_name,
                     "gene1": get_value_or_default(fusion_variant["@targeted-gene"]),
                     "gene2": get_value_or_default(fusion_variant["@other-gene"]),
                     "effect": get_value_or_default(fusion_variant["@type"].lower()),
