@@ -66,6 +66,21 @@ def get_non_human_content(nhc_dicts) -> list:
     return nhc_final
 
 
+def get_plasma_tumor_fraction(genes) -> str:
+    ptf_dict = {
+        "Elevated Tumor Fraction": "Elevated",
+        "Elevated Tumor Fraction Not Detected": "Not Elevated",
+    }
+    ptf_entry = [
+        entry for entry in genes.get("Gene", {}) if entry.get("Name", "") == "Tumor Fraction"
+    ]
+    if ptf_entry:
+        ptf_val = ptf_entry[0].get("Alterations", "").get("Alteration", "").get("Name", "")
+        return [value for (key, value) in ptf_dict.items() if key == ptf_val][0]
+    else:
+        return None
+
+
 def get_test_yml(
     customer_info_dict: dict,
     results_payload_dict: dict,
@@ -84,7 +99,8 @@ def get_test_yml(
     non_human_content = variant_report.get("non-human-content", {})
     report_properties = results_payload_dict.get("FinalReport", {}).get("reportProperties", {})
     report_property = report_properties.get("reportProperty", [])
-    genes = results_payload_dict.get("FinalReport", {}).get("Genes", [])
+    genes = results_payload_dict.get("FinalReport", {}).get("Genes", {})
+    plasma_tumor_fraction = get_plasma_tumor_fraction(genes)
     properties = report_property if isinstance(report_property, list) else [report_property]
     gw_loh = next(
         (prop for prop in properties if prop.get("@key") == "LossOfHeterozygosityScore"),
@@ -217,4 +233,8 @@ def get_test_yml(
 
         yaml_file["reportFile"] = f"{phc_output_dir}/{base_xml_name}/{base_xml_name}.report.pdf"
 
+    # add plasma tumor fraction
+    if plasma_tumor_fraction:
+        yaml_file["plasmaTumorFraction"] = plasma_tumor_fraction
+
     return yaml_file
